package Acme::Dzil::Plugin::Tester;

use strict;
use warnings;

our $VERSION = '0.04';

1;

# ABSTRACT: A distro that exists so I can test various dzil plugins

__END__

=pod

=head1 NAME

Acme::Dzil::Plugin::Tester - A distro that exists so I can test various dzil plugins

=head1 VERSION

version 0.04

=head1 DESCRIPTION

It's really hard to test certain dzil plugins (especially release plugins)
without actually doing a release. This distro lets me test them.

=head1 AUTHOR

Dave Rolsky <autarch@urth.org>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2015 by Dave Rolsky.

This is free software, licensed under:

  The Artistic License 2.0 (GPL Compatible)

=cut
